HWBoxBorder class

A simple border for HWBoxDecoration.

Glance AppWidget does not expose stroke alignment, so borders are emitted as an inside border approximation on Android.

Constructors

HWBoxBorder({double radius = 0.0, required double thickness, required HWColor color})
const

Properties

color HWColor
final
hashCode int
The hash code for this object.
no setterinherited
kotlinImports Set<String>
no setter
radius double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swiftViewModifiers Set<String>
no setter
thickness double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited