HWBoxDecoration class

A box decoration with an optional background color and border.

Constructors

HWBoxDecoration({HWColor? color, HWBoxBorder? border})
const

Properties

border HWBoxBorder?
final
color HWColor?
final
hashCode int
The hash code for this object.
no setterinherited
kotlinImports Set<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swiftViewModifiers Set<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited