HWTextStyle class

A class representing text styling options for HWText.

Implemented types
Implementers

Constructors

HWTextStyle({double? fontSize, HWFontWeight? fontWeight, HWColor? color, bool? italic, bool? underline, bool? lineThrough, HWTextStyle? baseStyle})
const

Properties

baseStyle HWTextStyle?
final
color HWColor?
final
fontSize double?
final
fontWeight HWFontWeight?
final
hashCode int
The hash code for this object.
no setterinherited
italic bool?
final
kotlinImports Set<String>
The set of Kotlin imports required by this element.
no setteroverride
lineThrough bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swiftViewModifiers Set<String>
The set of Swift view declarations/modifiers required by this element (e.g., @Environment(\\.colorScheme) var colorScheme).
no setteroverride
underline bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toKotlin(int indent, {required String dataExpr}) String
Generates the Kotlin code. indent is the number of indentation levels (4 spaces each). dataExpr is the Kotlin expression to access data fields.
override
toString() String
A string representation of this object.
inherited
toSwift(int indent, {required String dataExpr}) String
Generates the SwiftUI code. indent is the number of indentation levels (4 spaces each). dataExpr is the Swift expression to access data fields (e.g. "entry.widgetData").
override

Operators

operator ==(Object other) bool
The equality operator.
inherited