home_widget_generator_cli library

Libraries exported exclusively for use by the home_widget_cli package.

These exports are considered internal implementation details of the home_widget_generator and are not subject to semantic versioning guarantees for general public use.

Classes

WidgetTreeParser
Parses a @HomeWidget annotation into an HWWidget.
WidgetValueDecoder
Decodes a DartObject representing a widget tree into an HWWidget.

Functions

injectGlanceModifier(String code, String modifier) String
Helper to parse a typical Compose call (e.g. Column { or Text(...)) and inject a modifier string (e.g. fillMaxSize()).
wrapGlanceRootContent(String code, {required String modifier, String contentAlignment = 'Alignment.Center'}) String
Wraps the widget tree in a full-size Box with contentAlignment.