WidgetTreeParser class

Parses a @HomeWidget annotation into an HWWidget.

This uses the analyzer to compute the constant value of the annotation and then decodes it using WidgetValueDecoder.

Constructors

WidgetTreeParser(ElementAnnotation annotation)

Properties

annotation → ElementAnnotation
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse() HWWidget
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited