WidgetValueDecoder class

Decodes a DartObject representing a widget tree into an HWWidget.

This uses the analyzer's constant evaluation to read the values of @HomeWidget annotations and their fields.

Constructors

WidgetValueDecoder(DartObject? object)

Properties

hashCode int
The hash code for this object.
no setterinherited
object → DartObject?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode() HWWidget
decodeRecursive(DartObject? obj) HWWidget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decodeBoxBorder(DartObject? obj) HWBoxBorder?
decodeBoxDecoration(DartObject? obj) HWBoxDecoration?
decodeColor(DartObject? obj) HWColor?
decodeDataType(DartObject? obj) HWDataType?
decodeEdgeInsets(DartObject? obj) HWEdgeInsets?
decodeEnum<T>(DartObject? obj, List<T> values) → T?
decodeTextAlign(DartObject? obj) HWTextAlign?
decodeTextStyle(DartObject? obj) HWTextStyle?
getField(DartObject obj, String name) → DartObject?