HWConditional class abstract
Abstract base class for conditional widgets.
- Inheritance
- Implemented types
- Implementers
Constructors
- HWConditional()
-
const
Properties
-
dataDependencies
→ Set<
HWDataType> -
The set of data dependencies required by this widget.
no setteroverride
- firstBranch → HWWidget
-
The widget to render if the condition is met.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kotlinImports
→ Set<
String> -
The set of Kotlin imports required by this element.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondBranch → HWWidget
-
The widget to render if the condition is not met.
no setter
-
swiftViewModifiers
→ Set<
String> -
The set of Swift view declarations/modifiers required by this element
(e.g.,
@Environment(\\.colorScheme) var colorScheme).no setteroverride
Methods
-
conditionKotlin(
{required String dataExpr}) → String - Returns the Kotlin condition expression.
-
conditionSwift(
{required String dataExpr}) → String - Returns the Swift condition expression.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toKotlin(
int indent, {required String dataExpr}) → String -
Generates the Kotlin code for this widget.
indentis the number of indentation levels (4 spaces each).dataExpris the Kotlin expression to access data fields.dataFieldsmaps field keys to their types.override -
toString(
) → String -
A string representation of this object.
inherited
-
toSwift(
int indent, {required String dataExpr}) → String -
Generates the SwiftUI code for this widget.
indentis the number of indentation levels (4 spaces each).dataExpris the Swift expression to access data fields (e.g. "entry.widgetData").dataFieldsmaps field keys to their types (e.g. 'title' -> HWString()).override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited