A common interface for elements that can generate Swift and Kotlin code with their associated imports.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kotlinImports
→ Set<
String> -
The set of Kotlin imports required by this element.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
swiftViewModifiers
→ Set<
String> -
The set of Swift view declarations/modifiers required by this element
(e.g.,
@Environment(\\.colorScheme) var colorScheme).no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toKotlin(
int indent, {required String dataExpr}) → String -
Generates the Kotlin code.
indentis the number of indentation levels (4 spaces each).dataExpris the Kotlin expression to access data fields. -
toString(
) → String -
A string representation of this object.
inherited
-
toSwift(
int indent, {required String dataExpr}) → String -
Generates the SwiftUI code.
indentis the number of indentation levels (4 spaces each).dataExpris the Swift expression to access data fields (e.g. "entry.widgetData").
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited